## supergpt
This is a chatbot by a 8-year-old child named Thai Lam.
## Required:
google-genai >=1.24.0
python >=3.9
## How to use
Install package:
```sh
pip install supergpt
```
Use in file:
```python
import supergpt
# It will make a window
```
©️2025 PyPI.
No copy.